'use strict' // Strict mode
module.exports = function (inputFiles, outputFile, callback) {
  // Set outputFile to 'out.pdf' if it's not defined
  outputFile = outputFile || 'out.pdf'
  // Require child_process module to access spawn and execFile functions
  let {spawn, execFile} = require('child_process')
  // Require the default NodeJS path module
  let path = require('path')
  // initialize the array of arguments to be passed to pdfmerge.py
  let argumentsArray = [path.join(__dirname, '/pdfmergepy/pdfmerge.py')]
  // Push inputFiles to argumentsArray
  for (let i = 0; i < inputFiles.length; i++) {
    argumentsArray.push(inputFiles[i])
  }
  // Push '-o' to the argumentsArray, -o = output file
  argumentsArray.push('-o')
  // Push the specified output file to argumentsArray
  argumentsArray.push(outputFile)
  // Start pdfmerge python process
  let pdfmergepy = spawn('python', argumentsArray)
  // log stdout data to the console
  pdfmergepy.stdout.on('data', function(data){
    console.log(data)
  })
  // If the error contains 'PdfFileWriter', then it's most likely related to PyPDF2
  pdfmergepy.stderr.on('data', function(data){
    if (data.toString().match('PdfFileWriter')) {
      console.log('Install PyPDF2!')
    }
    console.log(data.toString())
  })
  // Success is code 0, Something other than 0 is not successful.
  pdfmergepy.on('close', function(code){
    if (code == 0) {
      console.log('Success!') 
    } else {
      console.log('Unsuccessful!')
    }
    if(typeof callback == "function"){
      callback()
    }
  })
  // If error, check for the code and log to console
  pdfmergepy.on('error', (err) => {
    if (err.code == 'ENOENT') {
      console.log('Please check if the PATH is correct!')
    }
  })
}
// Eskai - Mimi
